summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice/cvsprocesswidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/cvsservice/cvsprocesswidget.cpp')
-rw-r--r--vcs/cvsservice/cvsprocesswidget.cpp80
1 files changed, 40 insertions, 40 deletions
diff --git a/vcs/cvsservice/cvsprocesswidget.cpp b/vcs/cvsservice/cvsprocesswidget.cpp
index 2d41a356..d2e78da6 100644
--- a/vcs/cvsservice/cvsprocesswidget.cpp
+++ b/vcs/cvsservice/cvsprocesswidget.cpp
@@ -9,8 +9,8 @@
* *
***************************************************************************/
-#include <qpainter.h>
-#include <qregexp.h>
+#include <tqpainter.h>
+#include <tqregexp.h>
#include <dcopref.h>
#include <kstatusbar.h>
@@ -43,41 +43,41 @@ int g_dcopErrCounter = 0;
#endif
-CvsProcessWidget::CvsProcessWidget( CvsService_stub *service, CvsServicePart *part, QWidget *parent, const char *name )
+CvsProcessWidget::CvsProcessWidget( CvsService_stub *service, CvsServicePart *part, TQWidget *parent, const char *name )
: DCOPObject( "CvsProcessWidgetDCOPIface" ),
- QTextEdit( parent, name ),
+ TQTextEdit( parent, name ),
m_part( part ), m_service( service ), m_job( 0 )
{
setReadOnly( true );
setTextFormat( Qt::LogText );
- QStyleSheetItem *style = 0;
- style = new QStyleSheetItem( styleSheet(), "goodtag" );
+ TQStyleSheetItem *style = 0;
+ style = new TQStyleSheetItem( styleSheet(), "goodtag" );
style->setColor( "black" );
- style = new QStyleSheetItem( styleSheet(), "errortag" );
+ style = new TQStyleSheetItem( styleSheet(), "errortag" );
style->setColor( "red" );
- style->setFontWeight( QFont::Bold );
+ style->setFontWeight( TQFont::Bold );
- style = new QStyleSheetItem( styleSheet(), "infotag" );
+ style = new TQStyleSheetItem( styleSheet(), "infotag" );
style->setColor( "blue" );
- style = new QStyleSheetItem( styleSheet(), "cvs_conflict" );
+ style = new TQStyleSheetItem( styleSheet(), "cvs_conflict" );
style->setColor( "red" );
- style = new QStyleSheetItem( styleSheet(), "cvs_added" );
+ style = new TQStyleSheetItem( styleSheet(), "cvs_added" );
style->setColor( "green" );
- style = new QStyleSheetItem( styleSheet(), "cvs_removed" );
+ style = new TQStyleSheetItem( styleSheet(), "cvs_removed" );
style->setColor( "yellow" );
- style = new QStyleSheetItem( styleSheet(), "cvs_updated" );
+ style = new TQStyleSheetItem( styleSheet(), "cvs_updated" );
style->setColor( "lightblue" );
- style = new QStyleSheetItem( styleSheet(), "cvs_modified" );
+ style = new TQStyleSheetItem( styleSheet(), "cvs_modified" );
style->setColor( "darkgreen" );
- style = new QStyleSheetItem( styleSheet(), "cvs_unknown" );
+ style = new TQStyleSheetItem( styleSheet(), "cvs_unknown" );
style->setColor( "gray" );
}
@@ -105,9 +105,9 @@ bool CvsProcessWidget::isAlreadyWorking() const
void CvsProcessWidget::clear()
{
- QTextEdit::clear();
- this->m_errors = QString::null;
- this->m_output = QString::null;
+ TQTextEdit::clear();
+ this->m_errors = TQString::null;
+ this->m_output = TQString::null;
}
///////////////////////////////////////////////////////////////////////////////
@@ -130,17 +130,17 @@ bool CvsProcessWidget::startJob( const DCOPRef &aJob )
// establish connections to the signals of the cvs m_job
connectDCOPSignal( m_job->app(), m_job->obj(), "jobExited(bool, int)", "slotJobExited(bool, int)", true );
- connectDCOPSignal( m_job->app(), m_job->obj(), "receivedStdout(QString)", "slotReceivedOutput(QString)", true );
- connectDCOPSignal( m_job->app(), m_job->obj(), "receivedStderr(QString)", "slotReceivedErrors(QString)", true );
+ connectDCOPSignal( m_job->app(), m_job->obj(), "receivedStdout(TQString)", "slotReceivedOutput(TQString)", true );
+ connectDCOPSignal( m_job->app(), m_job->obj(), "receivedStderr(TQString)", "slotReceivedErrors(TQString)", true );
// get command line and add it to output buffer
- QString cmdLine = m_job->cvsCommand();
+ TQString cmdLine = m_job->cvsCommand();
m_part->mainWindow()->statusBar()->message( cmdLine );
kdDebug(9006) << "Running: " << cmdLine << endl;
// disconnect 3rd party slots from our signals
- disconnect( SIGNAL(jobFinished(bool, int)) );
+ disconnect( TQT_SIGNAL(jobFinished(bool, int)) );
showInfo( i18n("Started job: %1").arg( cmdLine ) );
@@ -181,12 +181,12 @@ void CvsProcessWidget::slotJobExited( bool normalExit, int exitStatus )
if (m_job)
{
disconnectDCOPSignal( m_job->app(), m_job->obj(), "jobExited(bool, int)", "slotJobExited(bool, int)" );
- disconnectDCOPSignal( m_job->app(), m_job->obj(), "receivedStdout(QString)", "slotReceivedOutput(QString)" );
- disconnectDCOPSignal( m_job->app(), m_job->obj(), "receivedStderr(QString)", "slotReceivedErrors(QString)" );
+ disconnectDCOPSignal( m_job->app(), m_job->obj(), "receivedStdout(TQString)", "slotReceivedOutput(TQString)" );
+ disconnectDCOPSignal( m_job->app(), m_job->obj(), "receivedStderr(TQString)", "slotReceivedErrors(TQString)" );
delete m_job;
m_job = 0;
}
- QString exitMsg = i18n("Job finished with exitCode == %1");
+ TQString exitMsg = i18n("Job finished with exitCode == %1");
showInfo( exitMsg.arg( exitStatus) );
m_part->core()->running( m_part, false );
@@ -197,15 +197,15 @@ void CvsProcessWidget::slotJobExited( bool normalExit, int exitStatus )
///////////////////////////////////////////////////////////////////////////////
-void CvsProcessWidget::slotReceivedOutput( QString someOutput )
+void CvsProcessWidget::slotReceivedOutput( TQString someOutput )
{
- kdDebug(9006) << "CvsProcessWidget::slotReceivedOutput(QString) here!" << endl;
+ kdDebug(9006) << "CvsProcessWidget::slotReceivedOutput(TQString) here!" << endl;
#ifdef MYDCOPDEBUG
g_dcopOutCounter++;
kdDebug(9006) << "MYDCOPDEBUG: dcopOutCounter == " << g_dcopOutCounter << endl;
#endif
- QStringList strings = m_outputBuffer.process( someOutput );
+ TQStringList strings = m_outputBuffer.process( someOutput );
if (strings.count() > 0)
{
m_output += strings;
@@ -216,15 +216,15 @@ void CvsProcessWidget::slotReceivedOutput( QString someOutput )
///////////////////////////////////////////////////////////////////////////////
-void CvsProcessWidget::slotReceivedErrors( QString someErrors )
+void CvsProcessWidget::slotReceivedErrors( TQString someErrors )
{
- kdDebug(9006) << "CvsProcessWidget::slotReceivedErrors(QString) here!" << endl;
+ kdDebug(9006) << "CvsProcessWidget::slotReceivedErrors(TQString) here!" << endl;
#ifdef MYDCOPDEBUG
g_dcopErrCounter++;
kdDebug(9006) << "MYDCOPDEBUG: dcopErrCounter == " << g_dcopErrCounter << endl;
#endif
- QStringList strings = m_errorBuffer.process( someErrors );
+ TQStringList strings = m_errorBuffer.process( someErrors );
if (strings.count() > 0)
{
m_errors += strings;
@@ -235,35 +235,35 @@ void CvsProcessWidget::slotReceivedErrors( QString someErrors )
///////////////////////////////////////////////////////////////////////////////
-void CvsProcessWidget::showInfo( const QStringList &msg )
+void CvsProcessWidget::showInfo( const TQStringList &msg )
{
- for (QStringList::const_iterator it = msg.begin(); it != msg.end(); ++it)
+ for (TQStringList::const_iterator it = msg.begin(); it != msg.end(); ++it)
append( "<infotag>" + (*it) + "</infotag>" );
}
///////////////////////////////////////////////////////////////////////////////
-void CvsProcessWidget::showError( const QStringList &msg )
+void CvsProcessWidget::showError( const TQStringList &msg )
{
- for (QStringList::const_iterator it = msg.begin(); it != msg.end(); ++it)
+ for (TQStringList::const_iterator it = msg.begin(); it != msg.end(); ++it)
append( "<errortag>" + (*it) + "</errortag>" );
}
///////////////////////////////////////////////////////////////////////////////
-void CvsProcessWidget::showOutput( const QStringList &msg )
+void CvsProcessWidget::showOutput( const TQStringList &msg )
{
- for (QStringList::const_iterator it = msg.begin(); it != msg.end(); ++it)
+ for (TQStringList::const_iterator it = msg.begin(); it != msg.end(); ++it)
{
// @todo here we can interpret lines as [C], [M], ...
- const QString &line = (*it);
+ const TQString &line = (*it);
//If the line already contains tags we need to replace the
//delimiters with the corresponding HTML code so that they are no longer
//recognized as tags.
//This will prevent QTextEdit from crashing on trying to parse the tags.
//This should fix BUG:99590
- QString lineNew(line);
+ TQString lineNew(line);
lineNew.replace("<", "&lt;");
lineNew.replace(">", "&gt;");
lineNew.replace("&", "&amp;");
@@ -235,35 +235,35 @@ void CvsProcessWidget::slotReceivedErrors( QString someErrors )
//delimiters with the corresponding HTML code so that they are no longer
//recognized as tags.
- //This will prevent QTextEdit from crashing on trying to parse the tags.
+ //This will prevent TQTextEdit from crashing on trying to parse the tags.
//This should fix BUG:99590